#[non_exhaustive]pub enum Predicate {
Sender(SenderFilter),
AffectedAddress(AffectedAddressFilter),
AffectedObject(AffectedObjectFilter),
MoveCall(MoveCallFilter),
EmitModule(EmitModuleFilter),
EventType(EventTypeFilter),
EventStreamHead(EventStreamHeadFilter),
}unstable only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Sender(SenderFilter)
Match transactions sent by the specified address.
AffectedAddress(AffectedAddressFilter)
Match transactions where the specified address’s state moved as a side effect: it owns an object after the txn, owned an object before the txn that was mutated/transferred away/deleted/wrapped, or its address-balance changed via an accumulator event.
AffectedObject(AffectedObjectFilter)
Match transactions whose effects include a change for the specified object.
MoveCall(MoveCallFilter)
Match transactions that made a Move call matching the specified filter.
EmitModule(EmitModuleFilter)
Match transactions that emitted an event whose package/module fields match the specified filter.
EventType(EventTypeFilter)
Match transactions that emitted an event with a type matching the specified filter.
EventStreamHead(EventStreamHeadFilter)
Match transactions that wrote to the specified authenticated event stream head.
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn merge(
field: &mut Option<Predicate>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Predicate>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.